@@ -3,6 +3,7 @@
 #' @template all
 #' @import httr
 #' @import plyr
+#' @export
 #' @param uuid A dataset UUID.
 #' @param callopts Pass on options to GET.
 #' @description 
@@ -12,7 +13,7 @@
 #' @examples \dontrun{
 #' dataset_metrics(uuid='3f8a1297-3259-4700-91fc-acc4170b27ce')
 #' }
-#' @export
+
 dataset_metrics <- function(uuid, callopts=list())
 {
   # Define function to get data
@@ -20,7 +21,9 @@ dataset_metrics <- function(uuid, callopts=list())
     url <- sprintf('http://api.gbif.org/v0.9/dataset_metrics/%s', x)
     tt <- GET(url, callopts)
     stop_for_status(tt)
-    content(tt)
+    assert_that(tt$headers$`content-type`=='application/json')
+    res <- content(tt, as = 'text', encoding = "UTF-8")
+    RJSONIO::fromJSON(res, simplifyWithNames = FALSE)
   }
   
   # Get data
