@@ -4,29 +4,27 @@
 #' @import grid ggplot2 maps
 #' @examples \dontrun{
 #' # Make a map of Puma concolor occurrences
-#' key <- gbif_lookup(name='Puma concolor', kingdom='plants')$speciesKey
-#' dat <- occ_search(taxonKey=key, return='data', limit=300)
+#' key <- name_backbone(name='Puma concolor', kingdom='plants')$speciesKey
+#' dat <- occ_search(taxonKey=key, return='data', limit=100)
 #' gbifmap(input=dat)
 #'
 #' # Plot more Puma concolor occurrences
 #' dat <- occ_search(taxonKey=key, return='data', limit=1200)
 #' nrow(dat)
 #' gbifmap(input=dat)
+#' 
+#' # More than 1 species
+#' library(plyr)
+#' splist <- c('Cyanocitta stelleri', 'Junco hyemalis', 'Aix sponsa')
+#' keys <- sapply(splist, function(x) name_backbone(name=x, kingdom='plants')$speciesKey,
+#'    USE.NAMES=FALSE)
+#' dat <- occ_search(taxonKey=keys, return='data', limit=50)
+#' gbifmap(ldply(dat))
 #' }
 #' @export
 gbifmap <- function(input = NULL, mapdatabase = "world", region = ".", 
                     geom = geom_point, jitter = NULL, customize = NULL)
-{
-  long = NULL
-  lat = NULL
-  group = NULL
-  longitude = NULL
-  latitude = NULL
-  name = NULL
-  
-#   if(!is.gbiflist(input))
-#     stop("Input is not of class gbiflist")
-
+{  
   tomap <- input[complete.cases(input$latitude, input$latitude), ]
   tomap <- tomap[!tomap$longitude==0 & !tomap$latitude==0,]
   tomap <- input[-(which(tomap$latitude <=90 || tomap$longitude <=180)), ]
@@ -47,6 +45,7 @@ gbifmap <- function(input = NULL, mapdatabase = "world", region = ".",
     theme_bw(base_size=14) +
     theme(legend.position = "bottom", legend.key = element_blank()) +
     guides(col = guide_legend(nrow=2)) +
+    coord_fixed(ratio = 1) +
     blanktheme() +
     theme2 + 
     customize
