@@ -104,4 +104,16 @@ NULL
 #' @name isocodes
 #' @docType data
 #' @keywords data
+NULL
+
+#' Type status options for GBIF searching
+#' 
+#' \itemize{
+#'   \item name. Name of type.
+#'   \item description. Description of the type.
+#' }
+#' 
+#' @name typestatus
+#' @docType data
+#' @keywords data
 NULL
\ No newline at end of file
