@@ -1,3 +1,18 @@
+get_hier <- function(x, h1, h2){
+  name <- data.frame(t(data.frame(x[names(x) %in% h1], stringsAsFactors=FALSE)), stringsAsFactors=FALSE)
+  if(nrow(name)==0){
+    data.frame(name=NA, key=NA, rank=NA, row.names=NULL, stringsAsFactors=FALSE)
+  } else {
+    name$ranks <- row.names(name)
+    name <- name[order(match(name$ranks, h1)), ]
+    tt <- as.matrix(name[,1])
+    row.names(tt) <- name[,2]
+    name <- tt
+    key <- t(data.frame(x[names(x) %in% h2], stringsAsFactors=FALSE))
+    data.frame(name=name, key=key, rank=row.names(name), row.names=NULL, stringsAsFactors=FALSE)
+  }
+}
+
 #' Parser for gbif data
 #' @param input A list
 #' @param fields (character) Default ('minimal') will return just taxon name, key, latitude, and 
@@ -8,14 +23,12 @@
 gbifparser <- function(input, fields='minimal'){
   parse <- function(x){
     x[sapply(x, length) == 0] <- "none"
-    h1 <- c('kingdom','phylum','clazz','order','family','genus','species')
+    h1 <- c('kingdom','phylum','class','order','family','genus','species')
     h2 <- c('kingdomKey','phylumKey','classKey','orderKey','familyKey','genusKey','speciesKey')
-    name <- t(data.frame(x[names(x) %in% h1]))
-    key <- t(data.frame(x[names(x) %in% h2]))
-    hier <- data.frame(name=name, key=key, rank=row.names(name), row.names=NULL)
+    hier <- get_hier(x, h1, h2)
     if(nrow(hier) == 0){
       if(!is.null(x[['species']])){
-        usename <- x[['species']]       
+        usename <- x[['species']]
       } else if(!is.null(x[['scientificName']]))
       {
         usename <- x[['scientificName']]
@@ -25,22 +38,23 @@ gbifparser <- function(input, fields='minimal'){
       }
     } else
     {
-      usename <- hier[[nrow(hier),"name"]]      
+      usename <- hier[[nrow(hier),"name"]]
     }
     #     geog <- data.frame(name=usename, x[!names(x) %in% c(h1,h2)])
-    alldata <- data.frame(name=usename, x)
+    x[names(x) %in% "issues"] <- paste(x[names(x) %in% "issues"][[1]], collapse=",")
+    alldata <- data.frame(name=usename, x, stringsAsFactors=FALSE)
     if(any(fields=='minimal')){
-      if(all(c('latitude','longitude') %in% names(alldata)))
+      if(all(c('decimalLatitude','decimalLongitude') %in% names(alldata)))
       {
-        alldata <- alldata[c('name','key','longitude','latitude')]
+        alldata <- alldata[c('name','key','decimalLatitude','decimalLongitude')]
       } else
       {
         alldata <- alldata['name']
-        alldata <- data.frame(alldata, key=NA, latitude=NA, longitude=NA)
+        alldata <- data.frame(alldata, key=NA, decimalLatitude=NA, decimalLongitude=NA, stringsAsFactors=FALSE)
       }
     } else if(any(fields == 'all')) 
     { 
-      NULL 
+      NULL
     } else
     {
       alldata <- alldata[names(alldata) %in% fields]
@@ -64,7 +78,7 @@ gbifparser <- function(input, fields='minimal'){
 #' @keywords internal
 gbifparser_verbatim <- function(input, fields='minimal'){
   parse <- function(x){
-    alldata <- data.frame(key=x$key, x$fields)
+    alldata <- data.frame(key=x$key, x$fields, stringsAsFactors=FALSE)
     if(any(fields=='minimal')){
       if(all(c('verbatimLatitude','verbatimLongitude') %in% names(alldata)))
       {
@@ -72,7 +86,7 @@ gbifparser_verbatim <- function(input, fields='minimal'){
       } else
       {
         name <- alldata['scientificName']
-        data.frame(name, verbatimLatitude=NA, verbatimLongitude=NA)
+        data.frame(name, verbatimLatitude=NA, verbatimLongitude=NA, stringsAsFactors=FALSE)
       }
     } else if(any(fields == 'all'))
     {
@@ -101,7 +115,7 @@ gbifparser_verbatim <- function(input, fields='minimal'){
 ldfast <- function(x, convertvec=FALSE){
   convert2df <- function(x){
     if(!inherits(x, "data.frame"))
-      data.frame(rbind(x))
+      data.frame(rbind(x), stringsAsFactors=FALSE)
     else
       x
   }
@@ -208,8 +222,7 @@ namelkupparser <- function(x){
       x[c('key','nubKey','parentKey','parent','kingdom','phylum',"clazz","order","family",
           "genus","kingdomKey","phylumKey","classKey","orderKey","familyKey","genusKey",
           "canonicalName","authorship","nameType","rank","numOccurrences")]
-    )
-  )
+    ), stringsAsFactors=FALSE)
 }
 
 
