@@ -5,7 +5,7 @@ test_that("type query returns the correct class", {
   expect_is(tt, "list")
   expect_is(tt$data, "data.frame")
   expect_is(tt$descriptions, "list")
-  expect_is(tt$data[1,1], "factor")
+  expect_is(tt$data[1,1], "character")
 })
 
 # Gets all datasets tagged with keyword "france".
@@ -13,7 +13,7 @@ tt <- dataset_search(keyword="france")
 test_that("keyword query returns the correct class", {
   expect_is(tt, "list")
   expect_is(tt$data, "data.frame")
-  expect_is(tt$data[1,1], "factor")
+  expect_is(tt$data[1,1], "character")
 })
 test_that("keyword query returns the correct value", {
   expect_equal(as.character(tt$data$publishingCountry[1]), "FR")
@@ -29,14 +29,14 @@ test_that("search query returns the correct class", {
   expect_is(tt$meta, "data.frame")
   expect_is(tt$descriptions, "list")
   expect_that(is.null(tt$facets), is_true())
-  expect_is(tt$data[1,1], "factor")
+  expect_is(tt$data[1,1], "character")
 })
 
 # Limited search
 tt <- dataset_search(type="OCCURRENCE", limit=2)
 test_that("limited search returns the correct class", {
   expect_is(tt$data, "data.frame")
-  expect_is(tt$data[1,1], "factor")
+  expect_is(tt$data[1,1], "character")
 })
 test_that("limited search returns the correct dims", {
   expect_equal(dim(tt$data), c(2,8))
