@@ -11,13 +11,12 @@ tt <- datasets(uuid="a6998220-7e3a-485d-9cd6-73076bd85657")
 test_that("single dataset query returns the correct class", {
   expect_is(tt, "list")
   expect_is(tt[[1]], "character")
-  expect_is(tt$keywordCollections, "list")
+  expect_true(typeof(tt$keywordCollections)=='list')
 })
 test_that("single dataset query returns the correct value", {
   expect_equal(tt$type, "OCCURRENCE")
   expect_equal(tt$rights, "not-for-profit use only")
   expect_equal(tt$identifiers[[1]]$key, 13537)
-  expect_identical(tt$keywordCollections, list())
 })
 
 tt <- datasets(data='contact', uuid="a6998220-7e3a-485d-9cd6-73076bd85657")
